# rds-core

É uma biblioteca pública em Python que condensa um conjunto de boas práticas para o desenvolvimento das aplicações 
que compõem a **Rede da Dados em Saúde (RDS) RDS**  do **Laboratório de Inovação Tecnológica em Saúde (LAIS)** 
e dos parceiros que contam com o LAIS para fazer suas próprias RDS, a exemplo 
RDS-RN e RDS-ES.

## Usando no seu projeto 

```
pip install rds-core
```

## Como desenvolver o projeto

```bash
docker build -t rds-core .
```

## Dicas

1. A versão pública da documentação fica disponível em http://rds.pages.lais.huol.ufrn.br/rds-core/

## Tipo de commits

- `feat:` novas funcionalidades.
- `fix:` correção de bugs.
- `refactor:` refatoração ou performances (sem impacto em lógica).
- `style:` estilo ou formatação de código (sem impacto em lógica).
- `test:` testes.
- `doc:` documentação no código ou do repositório.
- `env:` CI/CD ou settings.
- `build:` build ou dependências.